##  SaaS Hosting IT Components
When a SaaS application is linked to a catalog item, the associated SaaS hosting IT component fact sheet is automatically created and linked to the reference catalog. In this context, SaaS hosting means that an application is hosted as a SaaS product. Additionally, corresponding provider and tech category fact sheets are also created if they don't already exist.
Naming Conventions for SaaS Hosting IT Components Naming Convention | Notes
---|---
Provider name + IT component base name + SaaS hosting | Merger and acquisition naming conventions also apply to SaaS hosting IT components.


